# **What is `luma` CLI?**

`luma` is the [CLI](https://www.w3schools.com/whatis/whatis_cli.asp) for the **Luma Data Catalog**.

This versatile tool empowers users to:

- [x] Ingest metadata into the Luma Data Catalog
- [x] Update configurations in the Luma Data Catalog directly from the command line

To kickstart your journey with `luma`, please visit the [Getting Started](./getting_started.md) section.
